.. _grib-index_source:

############
 grib-index
############

The `grib-index` source is used to read GRIB files with the help of an
index file created with the `grib-index` :ref:`command
<grib-index_command>`.

See :ref:`create-grib-data` for more information.
